@@ -12,7 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301,
+# USA.
 
 """Cook a message's Subject header."""
 
@@ -247,12 +248,17 @@ def prefix_subject(mlist, msg, msgdata):
     if len(lines) > 1 and lines[1] and lines[1][0] in ' \t':
         ws = lines[1][0]
     msgdata['origsubj'] = subject
-    # The subject may be multilingual but we take the first charset
-    # as major one and try to decode. If it is decodable, returned
-    # subject is in one line and cset is properly set. If fail,
-    # subject is mime-encoded and cset is set as us-ascii. See detail
-    # for ch_oneline() (CookHeaders one line function).
+    # The subject may be multilingual but we take the first charset as major
+    # one and try to decode.  If it is decodable, returned subject is in one
+    # line and cset is properly set.  If fail, subject is mime-encoded and
+    # cset is set as us-ascii.  See detail for ch_oneline() (CookHeaders one
+    # line function).
     subject, cset = ch_oneline(subject)
+    # TK: Python interpreter has evolved to be strict on ascii charset code
+    # range.  It is safe to use unicode string when manupilating header
+    # contents with re module.  It would be best to return unicode in
+    # ch_oneline() but here is temporary solution.
+    subject = unicode(subject, cset)
     # If the subject_prefix contains '%d', it is replaced with the
     # mailing list sequential number.  Sequential number format allows
     # '%d' or '%05d' like pattern.
@@ -268,7 +274,7 @@ def prefix_subject(mlist, msg, msgdata):
     else:
         old_style = mm_cfg.OLD_STYLE_PREFIXING
     subject = re.sub(prefix_pattern, '', subject)
-    rematch = re.match('((RE|AW|SV)(\[\d+\])?:\s*)+', subject, re.I)
+    rematch = re.match('((RE|AW|SV|VS)(\[\d+\])?:\s*)+', subject, re.I)
     if rematch:
         subject = subject[rematch.end():]
         recolon = 'Re:'
@@ -279,6 +285,7 @@ def prefix_subject(mlist, msg, msgdata):
     if subject.strip() == '':
         subject = _('(no subject)')
         cset = Utils.GetCharSet(mlist.preferred_language)
+        subject = unicode(subject, cset)
     # and substitute %d in prefix with post_id
     try:
         prefix = prefix % mlist.post_id
@@ -289,21 +296,15 @@ def prefix_subject(mlist, msg, msgdata):
     if cset == 'us-ascii':
         try:
             if old_style:
-                h = ' '.join([recolon, prefix, subject])
+                h = u' '.join([recolon, prefix, subject])
             else:
-                h = ' '.join([prefix, recolon, subject])
-            if type(h) == UnicodeType:
-                h = h.encode('us-ascii')
-            else:
-                h = unicode(h, 'us-ascii').encode('us-ascii')
+                h = u' '.join([prefix, recolon, subject])
+            h = h.encode('us-ascii')
             h = uheader(mlist, h, 'Subject', continuation_ws=ws)
             del msg['subject']
             msg['Subject'] = h
-            ss = ' '.join([recolon, subject])
-            if _isunicode(ss):
-                ss = ss.encode('us-ascii')
-            else:
-                ss = unicode(ss, 'us-ascii').encode('us-ascii')
+            ss = u' '.join([recolon, subject])
+            ss = ss.encode('us-ascii')
             ss = uheader(mlist, ss, 'Subject', continuation_ws=ws)
             msgdata['stripped_subject'] = ss
             return
@@ -316,15 +317,8 @@ def prefix_subject(mlist, msg, msgdata):
     else:
         h = uheader(mlist, prefix, 'Subject', continuation_ws=ws)
         h.append(recolon)
-    # in seq version, subject header is already concatnated
-    if not _isunicode(subject):
-        try:
-            subject = unicode(subject, cset, 'replace')
-        except (LookupError, TypeError):
-            # unknown codec
-            cset = Utils.GetCharSet(mlist.preferred_language)
-            subject = unicode(subject, cset, 'replace')
-    subject = subject.encode(cset,'replace')
+    # TK: Subject is concatenated and unicode string.
+    subject = subject.encode(cset, 'replace')
     h.append(subject, cset)
     del msg['subject']
     msg['Subject'] = h
@@ -332,6 +326,7 @@ def prefix_subject(mlist, msg, msgdata):
     ss.append(subject, cset)
     msgdata['stripped_subject'] = ss
 
+
 
 def ch_oneline(s):
     # Decode header string in one line and convert into single charset
